<?php
require 'config.php';
require '2021-02-19-culture-as-a-common-good.cfg.php';
require 'templates/blog-header.php';
?>
<p>As anyone who is familiar with my works (and their licenses) would
know, I am very much a supporter of what's known as Free
Culture<sup><a href="#r1" >[1]</a></sup> and Free
Software<sup><a href="#r2" >[2]</a></sup>. Although for the rest of this
article I will be referring to both culture and software simply as
"Culture", since for the purpose of this article I see no point in
distinguishing between the two. I later found that the reason for this -
which I only understood intuitively - is that Culture is what we may
call a <i>Common Good</i>. Yet, at the same time I found this difficult
to reconcile with a recognition of Intellectual Property, to the extent
that for many years I simply rejected it. Yet I believe that this truly
is not contradictory, and in light of Church teaching regarding the
Universal Destination of Goods, we can fully understand how they
function together and use it to reinforce the case for Free Culture.</p>

<p>To begin, it's necessary to define a few things, foremost of which is
a <i>Common Good</i>. It's a term that we use a lot today, especially in
the realm of politics, but in such a vague manner that if one were to
ask what it means many of us would struggle to define it. Oxford
Dictionary defines it as "[t]he benefit or interests of all". Yet even
this is vague, at least when taken from the subjectivist mentality of
our era: one person's "interests" may be at odds with those of another.
Rather, especially since we're talking in terms of Culture as a form of
Intellectual Property, and therefore ownership, we're speaking of a more
economic or <i>substantive</i> definition. In this sense, what would
differentiate a Common Good from any other kind of Good is that the
intrinsic value of the share of each owner does not diminish when owned
by more people. This means that a Common Good is by its very nature a
Spiritual/Non-Material Good and <i>vice versa</i>. If someone owns a
whole cake, but chooses to share that cake with another person, the cake
must necessarily be divided (evenly or unevenly) such that both can own
a part of the cake, and therefore the value of the first person's share
must necessarily diminish. Meanwhile, if we were to speak of something
like knowledge, one can share knowledge that they have with another
person, yet not because of that do they now own less of that knowledge,
rather they continue to possess the entirety of that knowledge.</p>

<p>Perhaps an easier term to wrap our heads around that we're more
familiar with is that of <i>Intellectual Property</i>. Oxford Dictionary
defines it as "[i]ntangible property that is the result of creativity
[...]." For the purpose of this article, this is a rather appropriate
definition, as we're referring to a concept of ownership over the rights
to a given Spiritual/Non-Material Good.</p>

<p>From these two definitions we can begin to see how Culture is itself
both a Common Good and a form of Intellectual Property. Provided, it
must be specified that it is not the <i>instantiation</i> of a Cultural
Good that we are speaking of, but rather the idea which would compose
its <i>Formal Cause</i>. E.g. it is not the statue which an artists
makes that constitutes a Common Good, but rather it is the form that
defines it which is a Common Good. But from this recognition of Culture
as both a Common Good and a form of Intellectual Property, it would seem
that a dilemma arises: does not the nature of a Common Good directly
contradict that of Intellectual Property? It would seem this way, as a
Common Good tends towards broader ownership - and indeed it is good for
a Common Good to be owned as broadly as possible - yet Intellectual
Property hinders this broader ownership by limiting the ability to share
the Culture in question.</p>

<p>Here it is useful to attend to the Church's principle of the
<i>Universal Destination of Goods</i>:</p>

<blockquote>
	"God intended the earth with everything contained in it for the use
	of all human beings and peoples. Thus, under the leadership of
	justice and in the company of charity, created goods should be in
	abundance for all in like manner. Whatever the forms of property
	may be, as adapted to the legitimate institutions of peoples,
	according to diverse and changeable circumstances, attention must
	always be paid to this universal destination of earthly goods. In
	using them, therefore, man should regard the external things that he
	legitimately possesses not only as his own but also as common in the
	sense that they should be able to benefit not only him but also
	others."<br />
	- <i>Gaudium et Spes</i> § 69
</blockquote>

<p>In this sense, we are not solely speaking of Material Goods, but as
Pope Saint Paul VI points out, it applies to "[w]hatever the forms of
property may be." In this context, we see that "man should regard the
external things that he <b>legitimately possesses</b> not only as his
own but also as common in the sense that they should be able to benefit
not only him but also others." In other words, with regards to Culture
we can understand that it is legitimately possessed by its creator, and
is his Intellectual Property. Yet the creator has a responsibility in
using that which he owns for the benefit of "not only him but also
others." As such, a creator may choose using his own prudential
judgement to limit the access to his Intellectual Property to provide
for himself (by monopolizing on the creation of instances of his
creation to sell them) or even to help others. It may not always be
prudent to share a Common Good so broadly (as occurs with national
intelligence or personal information). But he must always consider that
his ownership must be beneficial not only to him, but to others as
well.</p>

<p>Finally, I believe it's important to discuss the role of the State
with regards to the Common Good, specifically in regards to Culture, and
truthfully I believe that this does not differ much from its role with
regards to Material Property. I do not wish to extend myself too far on
this topic, since the role of the State within society is a topic best
developed in its own article. Yet I do believe we can understand the
very basics of the role of the State in regards to its natural function
regarding Culture.</p>

<p>Fundamentally, the role of the State is to aid and guide its subjects
in fully realizing the <i>nature</i> of their being. The most
fundamental requisites of this being basic necessities (e.g. food,
water, shelter), but also extending further into Man's intellectual and
spiritual nature. So with regards to Culture, it is good for Man to
possess a broad and fundamental culture, which we would deem to be basic
education, and it is within the role of the State to enable this as it
sees most practical (by private or public means). Yet, the State must
only implicate itself in this regard if the selfishness of some causes
for certain fundamental Culture to be kept from others, or simply that
lower levels of society are unable to do so on their own. At this point,
the State has the authority to act by means of expedient to justly
purchase or (in the most extreme of situations) expropriate a creator of
his Intellectual Property. E.g. if there is a given institution which
has discovered a vaccine for a pandemic which is affecting the subjects
of the State at large, yet this institution is unable to produce the
amount needed, the State has the expedient to purchase from that
institution their Intellectual Property on how to create the vaccine and
share this with others so as to ensure a greater and more adequate
production.</p>

<p>Yet although the role of the State is well defined, what of the role
of us as creators? How can we decide whether we should maintain the
rights to our creations in full, or concede certain rights to our
Intellectual Property? Truthfully this is a prudential judgement that
each of us will have to make depending on the circumstances. But going
back to the quote from <i>Gaudium et Spes</i>, I believe we are given a
decent guide: we should consider the use of our property not only for
our own benefit, but also for that of others. Obviously, one must take
care of oneself, and therefore if the most practical manner of making a
living is by maintaining the right to one's property, one should do so.
Yet if one does not require of this, or the property would do greater
good if we were to license it in a manner allowing broader ownership,
this constitutes an act of charity. The act is even greater if the
property is not only beneficial to others, but needed.</p>

<p>Needless to say, there is no shortage of licenses with different
conditions, both for software and culture. For software projects one can
simply take a look at GitHub's <i>Choose a License</i>
page<sup><a href="#r3" >[3]</a></sup>, or for culture one may simply
choose from one of the many <i>Creative Commons</i>
licenses<sup><a href="#r4" >[4]</a></sup>. So it is not as though one
must either maintain all the rights to their works or give them all up.
Rather, one should adapt the license of their work to the circumstances
regarding the purpose of the work and what will best benefit oneself and
others.</p>

<label id="r1" >[1]</label>
<a
	   href="http://wiki.freeculture.org/Free_Culture_Definition"
	   target="_blank" >
	   http://wiki.freeculture.org/Free_Culture_Definition</a>
<br />
<label id="r2" >[2]</label>
<a
		href="https://www.gnu.org/philosophy/free-sw.en.html"
		target="_blank" >
		https://www.gnu.org/philosophy/free-sw.en.html</a>
<br />
<label id="r3" >[3]</label>
<a
	    href="https://choosealicense.com/"
		target="_blank" >
		https://choosealicense.com/</a>
<br />
<label id="r4" >[4]</label>
<a
	    href="https://creativecommons.org/choose/"
		target="_blank" >
		https://creativecommons.org/choose/</a>

<?php
require 'templates/blog-footer.php';
?>